/**
 * @file libkylog.h
 * @author chengxiaocui (chengxiaocui@kylinos.cn)
 * @brief 安全SDK日志(外部使用)
 * @version 0.1
 * @date 2024-03-19
 * 
 * @copyright Copyright (c) 2024
 * @defgroup 安全SDK日志
 * @{
 */
#ifndef _LIBKYLOGSEC_H
#define _LIBKYLOGSEC_H

#ifdef __cplusplus
extern "C" {
#endif

typedef enum _kdk_sec_log_status {
    KDK_SEC_LOG_DISABLE = 0,    //关闭
    KDK_SEC_LOG_ENABLE,         //开启
} kdk_sec_log_status;

/**
 * @brief 设置安全日志开关
 * 
 * @param status 日志开关状态，参见 kdk_sec_log_status
 * @return int 0 设置成功; -1 设置失败
 */
extern int kdk_sec_log_set_status(int status);

/**
 * @brief 获取安全日志开关
 * 
 * @return int 0 关闭；1 开启；-1 获取失败
 */
extern int kdk_sec_log_get_status();

/**
 * @brief 设置日志等级
 * 
 * @param level 日志等级，范围[3,7]，只记录<=level等级的日志
 * @return int 0 设置成功；-1 设置失败
 */
extern int kdk_sec_log_set_level(int level);

/**
 * @brief 获取日志等级
 * 
 * @return int [3,7] 对应日志等级；-1 获取失败
 */
extern int kdk_sec_log_get_level();

#ifdef __cplusplus
}
#endif
#endif
